Package 'PEcAn.PEPRMT'

Title: PEcAn Package for Integration of the PEPRMT Model
Description: This module provides functions to link PEPRMT to PEcAn.
Authors: Abigail Lewis, Patty Oikawa, James Holmquist
Maintainer: Abigail Lewis <[email protected]>
License: BSD_3_clause + file LICENSE
Version: 0.1.0.9000
Built: 2026-06-05 14:50:21 UTC
Source: https://github.com/PecanProject/pecan

Help Index


hls2model.PEPRMT

Description

hls2model for PEPRMT

Usage

hls2model.PEPRMT(
  in.path,
  in.prefix,
  outfolder,
  start_date,
  end_date,
  lat,
  lon,
  overwrite = FALSE,
  verbose = FALSE,
  ...
)

Arguments

in.path

location on disk where inputs are stored

in.prefix

prefix of input and output files

outfolder

location on disk where outputs will be stored

start_date, end_date

the start and end dates of the data to be downloaded (will only use the year part of the date)

lat, lon

latitude and longitude in degrees

overwrite

should existing files be overwritten

verbose

should the function be very verbose

...

additional arguments, currently ignored

Author(s)

Abigail Lewis (add names)


met2model.PEPRMT

Description

met2model for PEPRMT

Usage

met2model.PEPRMT(
  in.path,
  in.prefix,
  outfolder,
  start_date,
  end_date,
  overwrite = FALSE,
  verbose = FALSE,
  ...
)

Arguments

in.path

location on disk where inputs are stored

in.prefix

prefix of input and output files

outfolder

location on disk where outputs will be stored

start_date

the start date of the data to be downloaded (will only use the year part of the date)

end_date

the end date of the data to be downloaded (will only use the year part of the date)

overwrite

should existing files be overwritten

verbose

should the function be very verbose

...

additional arguments, currently ignored

Author(s)

Abigail Lewis (add names)


Function to convert PEPRMT model output to standard netCDF format

Description

Convert PEPRMT output to netCDF

Usage

model2netcdf.PEPRMT(
  outdir,
  sitelat,
  sitelon,
  start_date,
  end_date,
  delete_raw = FALSE
)

Arguments

outdir

Location of PEPRMT model output

sitelat

Latitude of the site

sitelon

Longitude of the site

start_date

Start time of the simulation

end_date

End time of the simulation

delete_raw

logical: remove out.csv after converting?

Details

Converts all output contained in a folder to netCDF.

Author(s)

Abigail Lewis


Write PEPRMT configuration files

Description

Writes a PEPRMT config file.

Usage

write.config.PEPRMT(defaults, trait.values, settings, run.id)

Arguments

defaults

list of defaults to process

trait.values

vector of samples for a given trait

settings

list of settings from pecan settings file

run.id

id of run

Details

Requires a pft xml object, a list of trait values for a single PEPRMT run, and the name of the file to create

Value

configuration file for PEPRMT for given run

Author(s)

Rob Kooper, edited by Abby Lewis