| Title: | PEcAn Package for Integration of the PEPRMT Model |
|---|---|
| Description: | This module provides functions to link PEPRMT to PEcAn. |
| Authors: | Abigail Lewis, Patty Oikawa, James Holmquist |
| Maintainer: | Abigail Lewis <[email protected]> |
| License: | BSD_3_clause + file LICENSE |
| Version: | 0.1.0.9000 |
| Built: | 2026-06-05 14:50:21 UTC |
| Source: | https://github.com/PecanProject/pecan |
hls2model for PEPRMT
hls2model.PEPRMT( in.path, in.prefix, outfolder, start_date, end_date, lat, lon, overwrite = FALSE, verbose = FALSE, ... )hls2model.PEPRMT( in.path, in.prefix, outfolder, start_date, end_date, lat, lon, overwrite = FALSE, verbose = FALSE, ... )
in.path |
location on disk where inputs are stored |
in.prefix |
prefix of input and output files |
outfolder |
location on disk where outputs will be stored |
start_date, end_date
|
the start and end dates of the data to be downloaded (will only use the year part of the date) |
lat, lon
|
latitude and longitude in degrees |
overwrite |
should existing files be overwritten |
verbose |
should the function be very verbose |
... |
additional arguments, currently ignored |
Abigail Lewis (add names)
met2model for PEPRMT
met2model.PEPRMT( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, verbose = FALSE, ... )met2model.PEPRMT( in.path, in.prefix, outfolder, start_date, end_date, overwrite = FALSE, verbose = FALSE, ... )
in.path |
location on disk where inputs are stored |
in.prefix |
prefix of input and output files |
outfolder |
location on disk where outputs will be stored |
start_date |
the start date of the data to be downloaded (will only use the year part of the date) |
end_date |
the end date of the data to be downloaded (will only use the year part of the date) |
overwrite |
should existing files be overwritten |
verbose |
should the function be very verbose |
... |
additional arguments, currently ignored |
Abigail Lewis (add names)
Convert PEPRMT output to netCDF
model2netcdf.PEPRMT( outdir, sitelat, sitelon, start_date, end_date, delete_raw = FALSE )model2netcdf.PEPRMT( outdir, sitelat, sitelon, start_date, end_date, delete_raw = FALSE )
outdir |
Location of PEPRMT model output |
sitelat |
Latitude of the site |
sitelon |
Longitude of the site |
start_date |
Start time of the simulation |
end_date |
End time of the simulation |
delete_raw |
logical: remove out.csv after converting? |
Converts all output contained in a folder to netCDF.
Abigail Lewis
Writes a PEPRMT config file.
write.config.PEPRMT(defaults, trait.values, settings, run.id)write.config.PEPRMT(defaults, trait.values, settings, run.id)
defaults |
list of defaults to process |
trait.values |
vector of samples for a given trait |
settings |
list of settings from pecan settings file |
run.id |
id of run |
Requires a pft xml object, a list of trait values for a single PEPRMT run, and the name of the file to create
configuration file for PEPRMT for given run
Rob Kooper, edited by Abby Lewis